@@ -1,4 +1,4 @@
-BAUDRATES_LIST = ["9600", "19200", "38400", "57600", "115200"]
+BAUDRATES_LIST = ["9600", "19200", "38400", "57600", "115200", "230400", "460800", "921600"]
 DEFAULT_BAUDRATE = 9600
 
 THEME_SETTINGS = {
